@@ -40,7 +40,7 @@ main (int argc, char *argv [])
    model = g_hash_table_lookup (sysinfo->cpuinfo [1].values, "model name");
 
    printf ("\nProcessor Model: %s\n", g_strdup (model));
-   printf ("Number of Cores: %lu\n\n", sysinfo->ncpu);
+   printf ("Number of Cores: %d\n\n", sysinfo->ncpu);
 
    glibtop_close ();
 
