@@ -40,7 +40,8 @@ End:
 
 typedef struct
 {
-  GHashTable *table;
+  GHashTable *table_fstype;
+  GHashTable *table_mntdir;
 } IgnoreList;
 
 
@@ -49,7 +50,8 @@ ignore_list_new(void)
 {
   IgnoreList* ig;
   ig = g_new(IgnoreList, 1);
-  ig->table = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
+  ig->table_fstype = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
+  ig->table_mntdir = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
   return ig;
 }
 
@@ -58,24 +60,38 @@ static void
 ignore_list_delete(IgnoreList* ig)
 {
   if (ig) {
-    g_hash_table_destroy(ig->table);
+    g_hash_table_destroy(ig->table_fstype);
+    g_hash_table_destroy(ig->table_mntdir);
     g_free(ig);
   }
 }
 
 
 static void
-ignore_list_add(IgnoreList* ig, const char* fs)
+ignore_list_add_fstype(IgnoreList* ig, const char* fstype)
 {
-  g_hash_table_insert(ig->table, g_strdup(fs), GINT_TO_POINTER(1));
+  g_hash_table_insert(ig->table_fstype, g_strdup(fstype), GINT_TO_POINTER(1));
 }
 
+static void
+ignore_list_add_mntdir(IgnoreList* ig, const char* mntdir)
+{
+  g_hash_table_insert(ig->table_mntdir, g_strdup(mntdir), GINT_TO_POINTER(1));
+}
 
 static gboolean
-ignore_list_has(IgnoreList* ig, const char* fs)
+ignore_list_has_fstype(IgnoreList* ig, const char* fstype)
 {
   gpointer data;
-  data = g_hash_table_lookup(ig->table, fs);
+  data = g_hash_table_lookup(ig->table_fstype, fstype);
+  return data != NULL;
+}
+
+static gboolean
+ignore_list_has_mntdir(IgnoreList* ig, const char* mntdir)
+{
+  gpointer data;
+  data = g_hash_table_lookup(ig->table_mntdir, mntdir);
   return data != NULL;
 }
 
@@ -84,7 +100,7 @@ ignore_list_has(IgnoreList* ig, const char* fs)
 
 
 static gboolean
-ignore_fs(const char *fstype, IgnoreList** ig)
+ignore_fs(const char *mntdir, const char *fstype, IgnoreList** ig)
 {
   if (!*ig) {
     FILE* fs;
@@ -92,24 +108,43 @@ ignore_fs(const char *fstype, IgnoreList** ig)
 
     *ig = ignore_list_new();
 
-    ignore_list_add(*ig, "none");
+    ignore_list_add_fstype(*ig, "none");
 
     if ((fs = fopen("/proc/filesystems", "r")) != NULL) {
       while (fgets(line, sizeof line, fs)) {
-	if (!strncmp(line, "nodev", 5)) {
+	if (!strncmp(line, "nodev", 5) && strncmp(line+strlen(line)-4, "zfs", 3)) {
 	  char *type;
 	  type = g_strstrip(line + 5);
-	  ignore_list_add(*ig, type);
+	  ignore_list_add_fstype(*ig, type);
 	}
       }
       fclose(fs);
     }
+
+    if ((fs = fopen("/run/mount/utab", "r")) != NULL) {
+	size_t len = 0;
+	char *uline = NULL;
+
+	while (getline(&uline, &len, fs) != -1) {
+	  if (strstr(uline, "x-gdu.hide")) {
+	    char * pch = strtok (uline, " ");
+	    while (pch != NULL) {
+	      if (!strncmp(pch, "TARGET=", 7)) {
+		ignore_list_add_mntdir(*ig, pch+7);
+	      }
+	      pch = strtok (NULL, " ");
+	    }
+	  }
+	}
+
+	free(uline);
+	fclose(fs);
+    }
   }
 
-  return ignore_list_has(*ig, fstype);
+  return ignore_list_has_fstype(*ig, fstype) || ignore_list_has_mntdir(*ig, mntdir);
 }
 
-
 glibtop_mountentry *
 glibtop_get_mountlist_s(glibtop *server, glibtop_mountlist *buf, int all_fs)
 {
@@ -118,7 +153,6 @@ glibtop_get_mountlist_s(glibtop *server, glibtop_mountlist *buf, int all_fs)
   GArray* entries;
   IgnoreList* ig = NULL;
 
-  glibtop_init_r(&server, 0, 0);
   memset(buf, 0, sizeof(glibtop_mountlist));
 
   /* wild guess, preallocate 8 entries
@@ -137,7 +171,7 @@ glibtop_get_mountlist_s(glibtop *server, glibtop_mountlist *buf, int all_fs)
       const char *devopt;
       gsize len;
 
-      if (!all_fs && ignore_fs(mnt->mnt_type, &ig))
+      if (!all_fs && ignore_fs(mnt->mnt_dir, mnt->mnt_type, &ig))
 	continue;
 
       len = entries->len;
